asr.pdos
========

.. automodule:: asr.pdos

   
   
   .. rubric:: Functions

   
   .. autofunction:: calculate_pdos
   .. autofunction:: dos_at_ef
   .. autofunction:: get_l_a
   .. autofunction:: get_ordered_syl_dict
   .. autofunction:: get_yl_colors
   .. autofunction:: pdos
   .. autofunction:: plot_pdos
   .. autofunction:: plot_pdos_nosoc
   .. autofunction:: plot_pdos_soc
   .. autofunction:: raw_spinorbit_orbital_LDOS_hack
   .. autofunction:: webpanel
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: SOCDOS
   .. autoclass:: SOCDescriptor
   
   

   
   
   